@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (C) 2015-2016 Regents of the University of California
+# Copyright (C) 2015-2021 Regents of the University of California
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +13,6 @@ from __future__ import absolute_import
 # limitations under the License.
 
 try:
-    from ._nacl import *
+    from ._nacl import *  # noqa
 except ImportError:
-    from ._dummy import *
+    from ._dummy import *  # noqa
