@@ -1,16 +1,16 @@
 import os
-import tempfile
 
 from toil.common import Toil
 from toil.job import Job
+from toil.lib.io import mkdtemp
 
 
-def helloWorld(message, memory="2G", cores=2, disk="3G"):
+def helloWorld(message):
     return f"Hello, world!, here's a message: {message}"
 
 
 if __name__ == "__main__":
-    jobstore: str = tempfile.mkdtemp("tutorial_quickstart")
+    jobstore: str = mkdtemp("tutorial_quickstart")
     os.rmdir(jobstore)
     options = Job.Runner.getDefaultOptions(jobstore)
     options.logLevel = "OFF"
