@@ -1,6 +1,6 @@
 from configargparse import ArgParser
 
-from toil.common import addOptions, Toil
+from toil.common import Toil, addOptions
 from toil.test import ToilTest
 
 
@@ -8,6 +8,7 @@ class OptionsTest(ToilTest):
     """
     Class to test functionality of all Toil options
     """
+
     def test_default_caching_slurm(self):
         """
         Test to ensure that caching will be set to false when running on Slurm
@@ -30,7 +31,11 @@ class OptionsTest(ToilTest):
         addOptions(parser, jobstore_as_flag=True, wdl=False, cwl=False)
         # the kubernetes batchsystem (and I think all batchsystems including singlemachine) return False
         # for default_caching
-        test_args = ["--jobstore=example-jobstore", "--batchSystem=kubernetes", "--caching=True"]
+        test_args = [
+            "--jobstore=example-jobstore",
+            "--batchSystem=kubernetes",
+            "--caching=True",
+        ]
         options = parser.parse_args(test_args)
         with Toil(options) as toil:
             caching_value = toil.config.caching
