@@ -18,6 +18,7 @@ from configargparse import ArgumentParser
 
 from toil.common import Toil
 from toil.job import Job, JobDescription, TemporaryID
+from toil.resource import ModuleDescriptor
 from toil.test import ToilTest
 
 
@@ -30,7 +31,7 @@ class JobDescriptionTest(ToilTest):
         Job.Runner.addToilOptions(parser)
         options = parser.parse_args(args=[self.jobStorePath])
         self.toil = Toil(options)
-        self.assertEqual( self.toil, self.toil.__enter__() )
+        self.assertEqual(self.toil, self.toil.__enter__())
 
     def tearDown(self):
         self.toil.__exit__(None, None, None)
@@ -43,17 +44,31 @@ class JobDescriptionTest(ToilTest):
         Tests the public interface of a JobDescription.
         """
 
-        command = "by your command"
-        memory = 2^32
-        disk = 2^32
+        memory = 2 ^ 32
+        disk = 2 ^ 32
         cores = "1"
         preemptible = 1
 
-        j = JobDescription(command=command, requirements={"memory": memory, "cores": cores, "disk": disk, "preemptible": preemptible},
-                           jobName='testJobGraph', unitName='noName')
+        j = JobDescription(
+            requirements={
+                "memory": memory,
+                "cores": cores,
+                "disk": disk,
+                "preemptible": preemptible,
+            },
+            jobName="testJobGraph",
+            unitName="noName",
+        )
 
-        #Check attributes
-        self.assertEqual(j.command, command)
+        # Without a body, and with nothing to run, nextSuccessors will be None
+        self.assertEqual(j.has_body(), False)
+        self.assertEqual(j.nextSuccessors(), None)
+
+        # Attach a body so the job has something to do itself.
+        j.attach_body("fake", ModuleDescriptor.forModule("toil"))
+        self.assertEqual(j.has_body(), True)
+
+        # Check attributes
         self.assertEqual(j.memory, memory)
         self.assertEqual(j.disk, disk)
         self.assertEqual(j.cores, int(cores))
@@ -67,30 +82,40 @@ class JobDescriptionTest(ToilTest):
         self.assertEqual(j.predecessorsFinished, set())
         self.assertEqual(j.logJobStoreFileID, None)
 
-        #Check equals function (should be based on object identity and not contents)
-        j2 = JobDescription(command=command, requirements={"memory": memory, "cores": cores, "disk": disk, "preemptible": preemptible},
-                            jobName='testJobGraph', unitName='noName')
+        # Check equals function (should be based on object identity and not contents)
+        j2 = JobDescription(
+            requirements={
+                "memory": memory,
+                "cores": cores,
+                "disk": disk,
+                "preemptible": preemptible,
+            },
+            jobName="testJobGraph",
+            unitName="noName",
+        )
+        j2.attach_body("fake", ModuleDescriptor.forModule("toil"))
         self.assertNotEqual(j, j2)
         ###TODO test other functionality
 
     def testJobDescriptionSequencing(self):
-        j = JobDescription(command='command', requirements={},  jobName='unimportant')
+        j = JobDescription(requirements={}, jobName="unimportant")
 
-        j.addChild('child')
-        j.addFollowOn('followOn')
+        j.addChild("child")
+        j.addFollowOn("followOn")
 
-        # With a command, nothing should be ready to run
+        # With a body, nothing should be ready to run
+        j.attach_body("fake", ModuleDescriptor.forModule("toil"))
         self.assertEqual(list(j.nextSuccessors()), [])
 
-        # With command cleared, child should be ready to run
-        j.command = None
-        self.assertEqual(list(j.nextSuccessors()), ['child'])
+        # With body cleared, child should be ready to run
+        j.detach_body()
+        self.assertEqual(list(j.nextSuccessors()), ["child"])
 
         # Without the child, the follow-on should be ready to run
-        j.filterSuccessors(lambda jID: jID != 'child')
-        self.assertEqual(list(j.nextSuccessors()), ['followOn'])
+        j.filterSuccessors(lambda jID: jID != "child")
+        self.assertEqual(list(j.nextSuccessors()), ["followOn"])
 
         # Without the follow-on, we should return None, to be distinct from an
         # empty list. Nothing left to do!
-        j.filterSuccessors(lambda jID: jID != 'followOn')
+        j.filterSuccessors(lambda jID: jID != "followOn")
         self.assertEqual(j.nextSuccessors(), None)
