@@ -23,7 +23,7 @@ class CachedUnpicklingJobStoreTest(ToilTest):
         """
         for _ in range(2):
             options = Job.Runner.getDefaultOptions(self._getTestJobStorePath())
-            options.logLevel = 'INFO'
+            options.logLevel = "INFO"
             root = Job.wrapJobFn(parent)
             Job.Runner.startToil(root, options)
 
@@ -40,7 +40,7 @@ class ChainedIndexedPromisesTest(ToilTest):
     # https://github.com/BD2KGenomics/toil/issues/1021
     def test(self):
         options = Job.Runner.getDefaultOptions(self._getTestJobStorePath())
-        options.logLevel = 'INFO'
+        options.logLevel = "INFO"
         root = Job.wrapJobFn(a)
         self.assertEqual(Job.Runner.startToil(root, options), 42)
 
@@ -62,17 +62,18 @@ class PathIndexingPromiseTest(ToilTest):
     Test support for indexing promises of arbitrarily nested data structures of lists, dicts and
     tuples, or any other object supporting the __getitem__() protocol.
     """
+
     def test(self):
         options = Job.Runner.getDefaultOptions(self._getTestJobStorePath())
-        options.logLevel = 'INFO'
+        options.logLevel = "INFO"
         root = Job.wrapJobFn(d)
-        self.assertEqual(Job.Runner.startToil(root, options), ('b', 43, 3))
+        self.assertEqual(Job.Runner.startToil(root, options), ("b", 43, 3))
 
 
 def d(job):
     child = job.addChild(job.wrapFn(e))
-    return child.rv('a'), child.rv(42), child.rv('c', 2)
+    return child.rv("a"), child.rv(42), child.rv("c", 2)
 
 
 def e():
-    return {'a': 'b', 42: 43, 'c': [1, 2, 3]}
+    return {"a": "b", 42: 43, "c": [1, 2, 3]}
