@@ -11,93 +11,92 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import argparse
+from collections.abc import Callable
 import os
-import shutil
+from pathlib import Path
 
 from toil.exceptions import FailedJobsException
-from toil.job import Job
-from toil.test import ToilTest
+from toil.job import Job, JobFunctionWrappingJob
+
+import pytest
 
 
-class CleanWorkDirTest(ToilTest):
+class TestCleanWorkDir:
     """
     Tests testing :class:toil.fileStores.abstractFileStore.AbstractFileStore
     """
 
-    def setUp(self):
-        super().setUp()
-        self.testDir = self._createTempDir()
-
-    def tearDown(self):
-        super().tearDown()
-        shutil.rmtree(self.testDir)
-
-    def testNever(self):
-        retainedTempData = self._runAndReturnWorkDir("never", job=tempFileTestJob)
-        self.assertNotEqual(
-            retainedTempData,
-            [],
-            "The worker's temporary workspace was deleted despite "
-            "cleanWorkDir being set to 'never'",
-        )
-
-    def testAlways(self):
-        retainedTempData = self._runAndReturnWorkDir("always", job=tempFileTestJob)
-        self.assertEqual(
-            retainedTempData,
-            [],
-            "The worker's temporary workspace was not deleted despite "
-            "cleanWorkDir being set to 'always'",
-        )
-
-    def testOnErrorWithError(self):
+    def testNever(self, tmp_path: Path) -> None:
         retainedTempData = self._runAndReturnWorkDir(
-            "onError", job=tempFileTestErrorJob, expectError=True
+            tmp_path, "never", job=tempFileTestJob
         )
-        self.assertEqual(
-            retainedTempData,
-            [],
-            "The worker's temporary workspace was not deleted despite "
-            "an error occurring and cleanWorkDir being set to 'onError'",
-        )
-
-    def testOnErrorWithNoError(self):
-        retainedTempData = self._runAndReturnWorkDir("onError", job=tempFileTestJob)
-        self.assertNotEqual(
-            retainedTempData,
-            [],
+        assert retainedTempData != [], (
             "The worker's temporary workspace was deleted despite "
-            "no error occurring and cleanWorkDir being set to 'onError'",
+            "cleanWorkDir being set to 'never'"
         )
 
-    def testOnSuccessWithError(self):
+    def testAlways(self, tmp_path: Path) -> None:
         retainedTempData = self._runAndReturnWorkDir(
-            "onSuccess", job=tempFileTestErrorJob, expectError=True
+            tmp_path, "always", job=tempFileTestJob
         )
-        self.assertNotEqual(
-            retainedTempData,
-            [],
-            "The worker's temporary workspace was deleted despite "
-            "an error occurring and cleanWorkDir being set to 'onSuccesss'",
-        )
-
-    def testOnSuccessWithSuccess(self):
-        retainedTempData = self._runAndReturnWorkDir("onSuccess", job=tempFileTestJob)
-        self.assertEqual(
-            retainedTempData,
-            [],
+        assert retainedTempData == [], (
             "The worker's temporary workspace was not deleted despite "
-            "a successful job execution and cleanWorkDir being set to 'onSuccesss'",
+            "cleanWorkDir being set to 'always'"
         )
 
-    def _runAndReturnWorkDir(self, cleanWorkDir, job, expectError=False):
+    def testOnErrorWithError(self, tmp_path: Path) -> None:
+        retainedTempData = self._runAndReturnWorkDir(
+            tmp_path, "onError", job=tempFileTestErrorJob, expectError=True
+        )
+        assert retainedTempData == [], (
+            "The worker's temporary workspace was not deleted despite "
+            "an error occurring and cleanWorkDir being set to 'onError'"
+        )
+
+    def testOnErrorWithNoError(self, tmp_path: Path) -> None:
+        retainedTempData = self._runAndReturnWorkDir(
+            tmp_path, "onError", job=tempFileTestJob
+        )
+        assert retainedTempData != [], (
+            "The worker's temporary workspace was deleted despite "
+            "no error occurring and cleanWorkDir being set to 'onError'"
+        )
+
+    def testOnSuccessWithError(self, tmp_path: Path) -> None:
+        retainedTempData = self._runAndReturnWorkDir(
+            tmp_path, "onSuccess", job=tempFileTestErrorJob, expectError=True
+        )
+        assert retainedTempData != [], (
+            "The worker's temporary workspace was deleted despite "
+            "an error occurring and cleanWorkDir being set to 'onSuccesss'"
+        )
+
+    def testOnSuccessWithSuccess(self, tmp_path: Path) -> None:
+        retainedTempData = self._runAndReturnWorkDir(
+            tmp_path, "onSuccess", job=tempFileTestJob
+        )
+        assert retainedTempData == [], (
+            "The worker's temporary workspace was not deleted despite "
+            "a successful job execution and cleanWorkDir being set to 'onSuccesss'"
+        )
+
+    def _runAndReturnWorkDir(
+        self,
+        tmp_path: Path,
+        cleanWorkDir: str,
+        job: Callable[[JobFunctionWrappingJob], None],
+        expectError: bool = False,
+    ) -> list[str]:
         """
         Runs toil with the specified job and cleanWorkDir setting. expectError determines whether the test's toil
         run is expected to succeed, and the test will fail if that expectation is not met. returns the contents of
         the workDir after completion of the run
         """
-        options = Job.Runner.getDefaultOptions(self._getTestJobStorePath())
-        options.workDir = self.testDir
+        workdir = tmp_path / "testDir"
+        workdir.mkdir()
+        options = Job.Runner.getDefaultOptions(tmp_path / "jobstore")
+        options.workDir = str(workdir)
         options.clean = "always"
         options.cleanWorkDir = cleanWorkDir
         A = Job.wrapJobFn(job)
@@ -105,26 +104,30 @@ class CleanWorkDirTest(ToilTest):
             self._launchError(A, options)
         else:
             self._launchRegular(A, options)
-        return os.listdir(self.testDir)
+        return os.listdir(workdir)
 
-    def _launchRegular(self, A, options):
+    def _launchRegular(
+        self, A: JobFunctionWrappingJob, options: argparse.Namespace
+    ) -> None:
         Job.Runner.startToil(A, options)
 
-    def _launchError(self, A, options):
+    def _launchError(
+        self, A: JobFunctionWrappingJob, options: argparse.Namespace
+    ) -> None:
         try:
             Job.Runner.startToil(A, options)
         except FailedJobsException:
             pass  # we expect a job to fail here
         else:
-            self.fail("Toil run succeeded unexpectedly")
+            pytest.fail("Toil run succeeded unexpectedly")
 
 
-def tempFileTestJob(job):
+def tempFileTestJob(job: JobFunctionWrappingJob) -> None:
     with open(job.fileStore.getLocalTempFile(), "w") as f:
         f.write("test file retention")
 
 
-def tempFileTestErrorJob(job):
+def tempFileTestErrorJob(job: JobFunctionWrappingJob) -> None:
     with open(job.fileStore.getLocalTempFile(), "w") as f:
         f.write("test file retention")
     raise RuntimeError()  # test failure
