@@ -14,6 +14,7 @@
 """SSH into the toil appliance container running on the leader of the cluster."""
 import argparse
 import logging
+import socket
 import sys
 
 from toil.common import parser_with_common_options
@@ -22,6 +23,22 @@ from toil.statsAndLogging import set_logging_from_options
 
 logger = logging.getLogger(__name__)
 
+def have_ipv6() -> bool:
+    """
+    Return True if the IPv6 loopback interface is useable.
+    """
+
+    # We sniff for actual IPv6 like in
+    # https://github.com/urllib3/urllib3/pull/840/files in urllib3 (which we
+    # don't depend on)
+    if socket.has_ipv6:
+        # Built with IPv6 support
+        try:
+            socket.socket(socket.AF_INET6).bind(("::1", 0))
+            return True
+        except Exception:
+            pass
+    return False
 
 def main() -> None:
     parser = parser_with_common_options(
@@ -73,6 +90,12 @@ def main() -> None:
         ["-L", f"{options.grafana_port}:localhost:3000", "-L", "9090:localhost:9090"]
     )
 
+    if not have_ipv6():
+        # If we try to do SSH port forwarding without any other options, but
+        # IPv6 is turned off on the host, we might get complaints that we
+        # "Cannot assign requested address" on ports on [::1].
+        sshOptions.append("-4")
+
     try:
         cluster.getLeader().sshAppliance(
             *command,
